enum tloading_error {
  LOADING_ERROR_NO_FILE = 1,
  LOADING_ERROR_BAD_MAGIC,
  LOADING_ERROR_NO_SUPERCLASS,
  LOADING_ERROR_NO_INTERFACE,
  LOADING_ERROR_BAD_FIELDS,
  LOADING_ERROR_BAD_METHODS,
  LOADING_ERROR_BAD_ATTRIBUTES,
  LOADING_ERROR_OUT_OF_MEMORY,
  LOADING_ERROR_NO_CLASSPATH,
  LOADING_ERROR_BAD_CLASS_NAME
};

void printLoadingError(uint32 errcode);
